@@ -73,7 +73,9 @@ impl MainActivity {
                 }
                 // paste
                 (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_P) => {
-                    self.paste();
+                    if let Err(e) = self.paste(){
+                        self.mount_error(e.to_string().as_ref());
+                    }
                     None
                 }
 
@@ -323,7 +325,7 @@ impl MainActivity {
                     if let Some(Payload::One(Value::Str(url))) =
                         self.view.get_state(COMPONENT_INPUT_URL)
                     {
-                        self.youtube_dl(url);
+                        self.youtube_dl(&url);
                     }
                     self.umount_youtube_url();
                     None
@@ -340,7 +342,9 @@ impl MainActivity {
                     {
                         self.umount_confirmation_input();
                         if p == "DELETE" {
-                            self.delete_songs();
+                            if let Err(e) =self.delete_songs() {
+                                self.mount_error(format!("delete song error: {}",e).as_str());
+                            };
                         }
                     }
                     None
@@ -376,7 +380,9 @@ impl MainActivity {
                         if index != 0 {
                             return None;
                         }
-                        self.delete_song();
+                        if let Err(e) =self.delete_song() {
+                                self.mount_error(format!("delete song error: {}",e).as_str());
+                        };
                     }
                     None
                 }
@@ -442,13 +448,20 @@ impl MainActivity {
             return;
         }
 
+        let song = match self.current_song.as_ref() {
+            Some(song) => song,
+            None => return,
+        };
+
+        let artist = song.artist().unwrap_or("Unknown Artist");
+
         if time_pos > self.time_pos || time_pos < 2 {
             self.time_pos = time_pos;
             let props = self.view.get_props(COMPONENT_PROGRESS).unwrap();
             let props = progress_bar::ProgressBarPropsBuilder::from(props)
                 .with_progress(new_prog)
                 .with_texts(
-                    Some(format!("Playing: {}", song_title)),
+                    Some(format!("Playing: {} - {}", artist, song_title)),
                     format!(
                         "{}     :     {} ",
                         format_duration(Duration::from_secs(time_pos as u64)),
@@ -465,11 +478,6 @@ impl MainActivity {
             return;
         }
 
-        let song = match self.current_song.as_ref() {
-            Some(song) => song,
-            None => return,
-        };
-
         if song.lyric_frames.is_empty() {
             let props = self.view.get_props(COMPONENT_PARAGRAPH_LYRIC).unwrap();
             let props = paragraph::ParagraphPropsBuilder::from(props)
